- pkgs
Character vector of packages that are added to search space via
require() or import::from() so can be found by utils::find().
Generally will be the returned value from spot_pkgs(file_path, show_explicit_funs = TRUE).
- file_path
character vector of path to file.
- show_each_use
Logical, default is FALSE. If changed to TRUE will
return individual rows for each time a function is used (rather than just
once for the entire file).
- keep_search_list
Logical, default is FALSE. If changed to TRUE
will include entire search list for function. May be helpful for debugging
in cases where funspotr may not be doing a good job of recreating the
search list for identifying which packages function(s) came from. This will
print all packages in the search list for each function.
- copy_local
Logical, if changed to FALSE will not copy to a local
temporary folder prior to doing analysis. Many functions require file to
already be an .R file and for the file to exist locally. This should
generally not be set to TRUE unless these hold.
- print_pkgs_load_status
Logical, default is FALSE. If set to TRUE
will print a named vector of logicals showing whether packages are on
machine along with any warning messages that come when running require().
Will continue on to produce output of function.
- error_if_missing_pkg
Logical, default is FALSE. If set to TRUE then
print_pkgs_load_status = TRUE automatically. If a package is not
installed on the machine then will print load status of individual pkgs and
result in an error.
- keep_in_multiple_pkgs
Logical, default is FALSE. If set to TRUE
will include in the outputted dataframe a column in_multiple_pkgs:
logical, whether a function exists in multiple packages loaded (i.e. on the
search space of utils::find().